@@ -8,7 +8,7 @@ RSpec.describe Jekyll::SeoTag do
   let(:tag)       { "seo" }
   let(:text)      { "" }
   let(:output)    { Liquid::Template.parse("{% #{tag} #{text} %}").render!(context, {}) }
-  let(:json)      { output.match(%r!<script type=\"application/ld\+json\">(.*)</script>!m)[1] }
+  let(:json)      { output.match(%r!<script type="application/ld\+json">(.*)</script>!m)[1] }
   let(:json_data) { JSON.parse(json) }
   let(:paginator) { { "previous_page" => true, "previous_page_path" => "foo", "next_page" => true, "next_page_path" => "bar" } }
 
@@ -26,7 +26,12 @@ RSpec.describe Jekyll::SeoTag do
   end
 
   it "outputs meta generator" do
-    expect(output).to match(%r!Jekyll v#{Jekyll::VERSION}!i)
+    version = Jekyll::VERSION
+    expect(output).to match(%r!Jekyll v#{version}!i)
+  end
+
+  it "outputs JSON sorted by key" do
+    expect(json.strip).to eql('{"@context":"https://schema.org","@type":"WebPage","url":"/page.html"}')
   end
 
   it "outputs valid HTML" do
@@ -613,10 +618,11 @@ RSpec.describe Jekyll::SeoTag do
     context "with site.webmaster_verifications" do
       let(:site_verifications) do
         {
-          "google" => "foo",
-          "bing"   => "bar",
-          "alexa"  => "baz",
-          "yandex" => "bat",
+          "google"   => "foo",
+          "bing"     => "bar",
+          "alexa"    => "baz",
+          "yandex"   => "bat",
+          "facebook" => "bas",
         }
       end
 
@@ -641,6 +647,11 @@ RSpec.describe Jekyll::SeoTag do
         expected = %r!<meta name="yandex-verification" content="bat" />!
         expect(output).to match(expected)
       end
+
+      it "outputs facebook verification meta" do
+        expected = %r!<meta name="facebook-domain-verification" content="bas" />!
+        expect(output).to match(expected)
+      end
     end
 
     context "with site.google_site_verification" do
